@@ -199,14 +199,15 @@ class EventManager(FilteredQueryList):
             events_raw=self._get_events(query_infos['resultID'])
 
         except (NitroError, TimeoutError) as error :
-            if (retry >0 and ( any(match in str(error) for match in [
-                    'ResultUnavailable',
-                    'ERROR_JEC_ResponseNotAvailable',
-                    'UnknownList',
-                    'JobEngine_GetQueryResults_QueryNotFound_Unrecoverable']) 
-                or isinstance(error, TimeoutError)) ):
-                
-                log.warning('Retring after: '+str(error))
+            # if (retry >0 and ( any(match in str(error) for match in [
+            #         'ResultUnavailable',
+            #         'ERROR_JEC_ResponseNotAvailable',
+            #         'UnknownList',
+            #         'JobEngine_GetQueryResults_QueryNotFound_Unrecoverable']) 
+            #     or isinstance(error, TimeoutError)) ):
+            if retry > 0:
+                log.warning('Retring qry_load_data() after error: '+str(error))
+                time.sleep(0.2)
                 return self.qry_load_data(retry=retry-1)
             else: raise
 
@@ -1129,8 +1130,12 @@ class Event(NitroDict):
                 filters=[('IPSIDAlertID',id)],
                 fields=extra_fields,
                 limit=2)
-                
-            e.load_data()
+            try:
+                e.load_data()
+            except NitroError:
+                log.error("Query failed, can't load event's data from id with 1 year timerange, looking at the last 15 days only...")
+                e.start_time=datetime.now()-timedelta(days=15)
+                e.load_data()
 
             if len(e) == 1 :
                 return e[0]
